@@ -19,12 +19,9 @@
 //      builtins: VMBuiltinFunctionsArray,
 // }
 
-use crate::module::Module;
-use crate::BuiltinFunctionIndex;
-use cranelift_codegen::ir;
-use cranelift_wasm::{
-    DefinedGlobalIndex, DefinedMemoryIndex, DefinedTableIndex, FuncIndex, GlobalIndex, MemoryIndex,
-    TableIndex, TypeIndex,
+use crate::{
+    BuiltinFunctionIndex, DefinedGlobalIndex, DefinedMemoryIndex, DefinedTableIndex, FuncIndex,
+    GlobalIndex, MemoryIndex, Module, TableIndex, TypeIndex,
 };
 use more_asserts::assert_lt;
 use std::convert::TryFrom;
@@ -375,12 +372,6 @@ impl<P: PtrSize> VMOffsets<P> {
     pub fn size_of_vmtable_definition(&self) -> u8 {
         2 * self.pointer_size()
     }
-
-    /// The type of the `current_elements` field.
-    #[inline]
-    pub fn type_of_vmtable_definition_current_elements(&self) -> ir::Type {
-        ir::Type::int(u16::from(self.size_of_vmtable_definition_current_elements()) * 8).unwrap()
-    }
 }
 
 /// Offsets for `VMMemoryImport`.
